@@ -1,5 +1,7 @@
 from abc import ABC
+from typing import TypeVar
 
+from cognite.client.data_classes import Asset, Event, FileMetadata, Sequence, TimeSeries
 from cognite.client.data_classes.capabilities import (
     Capability,
     DataModelInstancesAcl,
@@ -19,6 +21,8 @@ from cognite_toolkit._cdf_tk.utils import humanize_collection
 
 from .data_model import INSTANCE_SOURCE_VIEW_ID, MODEL_ID, VIEW_SOURCE_VIEW_ID
 
+T_AssetCentricResource = TypeVar("T_AssetCentricResource", bound=Asset | Event | FileMetadata | TimeSeries | Sequence)
+
 
 class BaseMigrateCommand(ToolkitCommand, ABC):
     def source_acl(self, data_set_id: list[int]) -> Capability:
