@@ -1,7 +1,7 @@
 from ._applications import ChartIO
 from ._asset_centric import AssetIO, BaseAssetCentricIO, FileMetadataIO
 from ._base import StorageIO, TableStorageIO
-from ._data_classes import ModelList
+from ._data_classes import InstanceIdCSVList, InstanceIdRow, ModelList
 from ._instances import InstanceIO
 from ._raw import RawIO
 from ._selectors import (
@@ -31,6 +31,8 @@ __all__ = [
     "DataSetSelector",
     "FileMetadataIO",
     "InstanceIO",
+    "InstanceIdCSVList",
+    "InstanceIdRow",
     "InstanceSelector",
     "InstanceViewSelector",
     "ModelList",
