@@ -1,21 +1,17 @@
 from abc import ABC, abstractmethod
-from collections.abc import Hashable, Iterable
+from collections.abc import Iterable
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Generic, TypeVar
+from typing import Generic
 
 from cognite.client.data_classes._base import (
     T_CogniteResourceList,
-    WriteableCogniteResourceList,
 )
 from rich.console import Console
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.utils.fileio import SchemaColumn
-from cognite_toolkit._cdf_tk.utils.useful_types import JsonVal
-
-T_Selector = TypeVar("T_Selector", bound=Hashable)
-T_WritableCogniteResourceList = TypeVar("T_WritableCogniteResourceList", bound=WriteableCogniteResourceList)
+from cognite_toolkit._cdf_tk.utils.useful_types import T_ID, JsonVal, T_Selector, T_WritableCogniteResourceList
 
 
 @dataclass
@@ -25,7 +21,7 @@ class StorageIOConfig:
     value: JsonVal
 
 
-class StorageIO(ABC, Generic[T_Selector, T_CogniteResourceList, T_WritableCogniteResourceList]):
+class StorageIO(ABC, Generic[T_ID, T_Selector, T_CogniteResourceList, T_WritableCogniteResourceList]):
     """This is a base class for all storage classes in Cognite Toolkit
 
     It defines the interface for interacting with storage items in CDF, such as downloading,
@@ -54,6 +50,16 @@ class StorageIO(ABC, Generic[T_Selector, T_CogniteResourceList, T_WritableCognit
     def __init__(self, client: ToolkitClient) -> None:
         self.client = client
 
+    @abstractmethod
+    def as_id(self, item: dict[str, JsonVal] | object) -> T_ID:
+        """Convert an item to its corresponding ID.
+        Args:
+            item: The item to convert.
+        Returns:
+            The ID corresponding to the item.
+        """
+        raise NotImplementedError()
+
     @abstractmethod
     def download_iterable(
         self, selector: T_Selector, limit: int | None = None
@@ -142,7 +148,7 @@ class StorageIO(ABC, Generic[T_Selector, T_CogniteResourceList, T_WritableCognit
         raise NotImplementedError()
 
 
-class TableStorageIO(StorageIO[T_Selector, T_CogniteResourceList, T_WritableCogniteResourceList], ABC):
+class TableStorageIO(StorageIO[T_ID, T_Selector, T_CogniteResourceList, T_WritableCogniteResourceList], ABC):
     @abstractmethod
     def get_schema(self, selector: T_Selector) -> list[SchemaColumn]:
         """Get the schema of the table associated with the given selector.
