@@ -1,13 +1,33 @@
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from dataclasses import dataclass
+from functools import cached_property
 from pathlib import Path
-from typing import Literal
+from typing import Generic, Literal
 
 from cognite.client.data_classes.data_modeling import ViewId
 
+from cognite_toolkit._cdf_tk.storageio._data_classes import InstanceIdCSVList, T_ModelList
 from cognite_toolkit._cdf_tk.utils.file import to_directory_compatible
 
 
+@dataclass(frozen=True)
+class CSVFileSelector(Generic[T_ModelList], ABC):
+    """Data class for file-based data selection from CSV files."""
+
+    datafile: Path
+
+    @abstractmethod
+    def list_cls(self) -> type[T_ModelList]:
+        raise NotImplementedError()
+
+    @cached_property
+    def items(self) -> T_ModelList:
+        return self.list_cls().read_csv_file(self.datafile)
+
+    def __str__(self) -> str:
+        return f"{type(self).__name__}={self.datafile.name}"
+
+
 @dataclass(frozen=True)
 class AssetCentricSelector:
     """Data class for asset-centric data selection."""
@@ -55,8 +75,9 @@ class InstanceSelector:
 
 
 @dataclass(frozen=True)
-class InstanceFileSelector(InstanceSelector):
-    datafile: Path
+class InstanceFileSelector(CSVFileSelector[InstanceIdCSVList], InstanceSelector):
+    def list_cls(self) -> type[InstanceIdCSVList]:
+        return InstanceIdCSVList
 
     def get_schema_spaces(self) -> list[str] | None:
         raise NotImplementedError()
