@@ -1,11 +1,11 @@
 import inspect
 import re
 from pathlib import Path
-from typing import Any
+from typing import Any, TypeVar
 
 from cognite.client.data_classes._base import CogniteObject
 from cognite.client.utils._text import to_camel_case, to_snake_case
-from pydantic import TypeAdapter, ValidationError
+from pydantic import BaseModel, TypeAdapter, ValidationError
 from pydantic_core import ErrorDetails
 
 from cognite_toolkit._cdf_tk._parameters import ParameterSpecSet, read_parameters_from_dict
@@ -20,10 +20,12 @@ from cognite_toolkit._cdf_tk.tk_warnings import (
     UnusedParameterWarning,
     WarningList,
 )
+from cognite_toolkit._cdf_tk.tk_warnings.fileread import ResourceFormatWarning
 
 __all__ = ["validate_data_set_is_set", "validate_modules_variables", "validate_resource_yaml"]
 
-from cognite_toolkit._cdf_tk.tk_warnings.fileread import ResourceFormatWarning
+
+T_BaseModel = TypeVar("T_BaseModel", bound=BaseModel)
 
 
 def validate_modules_variables(variables: BuildVariables, filepath: Path) -> WarningList:
@@ -149,6 +151,26 @@ def validate_resource_yaml_pydantic(
     return warning_list
 
 
+def instantiate_class(
+    data: dict[str, Any], validation_cls: type[T_BaseModel], source_file: Path, strict: bool = False
+) -> T_BaseModel | ResourceFormatWarning:
+    """Instantiates a class from a dictionary using the given pydantic model.
+
+    Args:
+        data: The data to instantiate the class from.
+        validation_cls: The pydantic model to use for instantiation.
+        source_file: The source file of the resource.
+        strict: Whether to enforce types strictly.
+
+    Returns:
+        The instantiated class or a ResourceFormatWarning if validation failed.
+    """
+    try:
+        return validation_cls.model_validate(data, strict=strict)
+    except ValidationError as e:
+        return ResourceFormatWarning(source_file, tuple(_humanize_validation_error(e)))
+
+
 def _humanize_validation_error(error: ValidationError) -> list[str]:
     """Converts a ValidationError to a human-readable format.
 
@@ -197,11 +219,19 @@ def _humanize_validation_error(error: ValidationError) -> list[str]:
             "float_type",
             "time_type",
             "timedelta_type",
+            "dict_type",
         }:
             msg = f"{item['msg']}. Got {item['input']!r} of type {type(item['input']).__name__}."
         else:
             # Default to the Pydantic error message
             msg = item["msg"]
+
+        if error_type.endswith("dict_type") and len(loc) > 1:
+            # If this is a dict_type error for a JSON field, the location will be:
+            #  dict[str,json-or-python[json=any,python=tagged-union[list[...],dict[str,...],str,bool,int,float,none]]]
+            #  This is hard to read, so we simplify it to just the field name.
+            loc = tuple(["dict" if isinstance(x, str) and "json-or-python" in x else x for x in loc])
+
         if len(loc) > 1 and error_type in {"extra_forbidden", "missing"}:
             # We skip the last element as this is in the message already
             msg = f"In {as_json_path(loc[:-1])} {msg[:1].casefold()}{msg[1:]}"
